# coding: utf-8

"""
    Tator REST API

    Interface to the Tator backend.  # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from tator_openapi.configuration import Configuration


class AttributeType(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'autocomplete': 'AutocompleteService',
        'choices': 'list[str]',
        'default': 'object',
        'description': 'str',
        'dtype': 'str',
        'labels': 'list[str]',
        'maximum': 'float',
        'minimum': 'float',
        'name': 'str',
        'order': 'int',
        'required': 'bool',
        'use_current': 'bool'
    }

    attribute_map = {
        'autocomplete': 'autocomplete',
        'choices': 'choices',
        'default': 'default',
        'description': 'description',
        'dtype': 'dtype',
        'labels': 'labels',
        'maximum': 'maximum',
        'minimum': 'minimum',
        'name': 'name',
        'order': 'order',
        'required': 'required',
        'use_current': 'use_current'
    }

    def __init__(self, autocomplete=None, choices=None, default=None, description='', dtype=None, labels=None, maximum=None, minimum=None, name=None, order=0, required=False, use_current=None, local_vars_configuration=None):  # noqa: E501
        """AttributeType - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._autocomplete = None
        self._choices = None
        self._default = None
        self._description = None
        self._dtype = None
        self._labels = None
        self._maximum = None
        self._minimum = None
        self._name = None
        self._order = None
        self._required = None
        self._use_current = None
        self.discriminator = None

        self.autocomplete = autocomplete
        if choices is not None:
            self.choices = choices
        self.default = default
        if description is not None:
            self.description = description
        if dtype is not None:
            self.dtype = dtype
        if labels is not None:
            self.labels = labels
        if maximum is not None:
            self.maximum = maximum
        if minimum is not None:
            self.minimum = minimum
        if name is not None:
            self.name = name
        if order is not None:
            self.order = order
        if required is not None:
            self.required = required
        if use_current is not None:
            self.use_current = use_current

    @property
    def autocomplete(self):
        """Gets the autocomplete of this AttributeType.  # noqa: E501


        :return: The autocomplete of this AttributeType.  # noqa: E501
        :rtype: AutocompleteService
        """
        return self._autocomplete

    @autocomplete.setter
    def autocomplete(self, autocomplete):
        """Sets the autocomplete of this AttributeType.


        :param autocomplete: The autocomplete of this AttributeType.  # noqa: E501
        :type: AutocompleteService
        """

        self._autocomplete = autocomplete

    @property
    def choices(self):
        """Gets the choices of this AttributeType.  # noqa: E501

        Array of possible values for enum dtype.  # noqa: E501

        :return: The choices of this AttributeType.  # noqa: E501
        :rtype: list[str]
        """
        return self._choices

    @choices.setter
    def choices(self, choices):
        """Sets the choices of this AttributeType.

        Array of possible values for enum dtype.  # noqa: E501

        :param choices: The choices of this AttributeType.  # noqa: E501
        :type: list[str]
        """

        self._choices = choices

    @property
    def default(self):
        """Gets the default of this AttributeType.  # noqa: E501

        Boolean, integer, float, string, datetime, or [lon, lat].  # noqa: E501

        :return: The default of this AttributeType.  # noqa: E501
        :rtype: object
        """
        return self._default

    @default.setter
    def default(self, default):
        """Sets the default of this AttributeType.

        Boolean, integer, float, string, datetime, or [lon, lat].  # noqa: E501

        :param default: The default of this AttributeType.  # noqa: E501
        :type: object
        """

        self._default = default

    @property
    def description(self):
        """Gets the description of this AttributeType.  # noqa: E501

        Description of the attribute.  # noqa: E501

        :return: The description of this AttributeType.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this AttributeType.

        Description of the attribute.  # noqa: E501

        :param description: The description of this AttributeType.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def dtype(self):
        """Gets the dtype of this AttributeType.  # noqa: E501

        Data type of the attribute.  # noqa: E501

        :return: The dtype of this AttributeType.  # noqa: E501
        :rtype: str
        """
        return self._dtype

    @dtype.setter
    def dtype(self, dtype):
        """Sets the dtype of this AttributeType.

        Data type of the attribute.  # noqa: E501

        :param dtype: The dtype of this AttributeType.  # noqa: E501
        :type: str
        """
        allowed_values = ["bool", "int", "float", "enum", "string", "datetime", "geopos"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and dtype not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `dtype` ({0}), must be one of {1}"  # noqa: E501
                .format(dtype, allowed_values)
            )

        self._dtype = dtype

    @property
    def labels(self):
        """Gets the labels of this AttributeType.  # noqa: E501

        Array of labels for enum dtype.  # noqa: E501

        :return: The labels of this AttributeType.  # noqa: E501
        :rtype: list[str]
        """
        return self._labels

    @labels.setter
    def labels(self, labels):
        """Sets the labels of this AttributeType.

        Array of labels for enum dtype.  # noqa: E501

        :param labels: The labels of this AttributeType.  # noqa: E501
        :type: list[str]
        """

        self._labels = labels

    @property
    def maximum(self):
        """Gets the maximum of this AttributeType.  # noqa: E501

        Upper bound for int or float dtype.  # noqa: E501

        :return: The maximum of this AttributeType.  # noqa: E501
        :rtype: float
        """
        return self._maximum

    @maximum.setter
    def maximum(self, maximum):
        """Sets the maximum of this AttributeType.

        Upper bound for int or float dtype.  # noqa: E501

        :param maximum: The maximum of this AttributeType.  # noqa: E501
        :type: float
        """

        self._maximum = maximum

    @property
    def minimum(self):
        """Gets the minimum of this AttributeType.  # noqa: E501

        Lower bound for int or float dtype.  # noqa: E501

        :return: The minimum of this AttributeType.  # noqa: E501
        :rtype: float
        """
        return self._minimum

    @minimum.setter
    def minimum(self, minimum):
        """Sets the minimum of this AttributeType.

        Lower bound for int or float dtype.  # noqa: E501

        :param minimum: The minimum of this AttributeType.  # noqa: E501
        :type: float
        """

        self._minimum = minimum

    @property
    def name(self):
        """Gets the name of this AttributeType.  # noqa: E501

        Name of the attribute.  # noqa: E501

        :return: The name of this AttributeType.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this AttributeType.

        Name of the attribute.  # noqa: E501

        :param name: The name of this AttributeType.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def order(self):
        """Gets the order of this AttributeType.  # noqa: E501

        Integer specifying relative order this attribute is displayed in the UI. Negative values are hidden by default.  # noqa: E501

        :return: The order of this AttributeType.  # noqa: E501
        :rtype: int
        """
        return self._order

    @order.setter
    def order(self, order):
        """Sets the order of this AttributeType.

        Integer specifying relative order this attribute is displayed in the UI. Negative values are hidden by default.  # noqa: E501

        :param order: The order of this AttributeType.  # noqa: E501
        :type: int
        """

        self._order = order

    @property
    def required(self):
        """Gets the required of this AttributeType.  # noqa: E501

        True if this attribute is required for POST requests.  # noqa: E501

        :return: The required of this AttributeType.  # noqa: E501
        :rtype: bool
        """
        return self._required

    @required.setter
    def required(self, required):
        """Sets the required of this AttributeType.

        True if this attribute is required for POST requests.  # noqa: E501

        :param required: The required of this AttributeType.  # noqa: E501
        :type: bool
        """

        self._required = required

    @property
    def use_current(self):
        """Gets the use_current of this AttributeType.  # noqa: E501

        True to use current datetime as default for datetime dtype.  # noqa: E501

        :return: The use_current of this AttributeType.  # noqa: E501
        :rtype: bool
        """
        return self._use_current

    @use_current.setter
    def use_current(self, use_current):
        """Sets the use_current of this AttributeType.

        True to use current datetime as default for datetime dtype.  # noqa: E501

        :param use_current: The use_current of this AttributeType.  # noqa: E501
        :type: bool
        """

        self._use_current = use_current

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AttributeType):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AttributeType):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Tator REST API

    Interface to the Tator backend.  # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from tator_openapi.configuration import Configuration


class VideoSpec(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'codec': 'str',
        'fps': 'float',
        'gid': 'str',
        'height': 'int',
        'md5': 'str',
        'media_files': 'MediaFiles',
        'name': 'str',
        'num_frames': 'int',
        'progress_name': 'str',
        'section': 'str',
        'thumbnail_gif_url': 'str',
        'thumbnail_url': 'str',
        'type': 'int',
        'uid': 'str',
        'width': 'int'
    }

    attribute_map = {
        'codec': 'codec',
        'fps': 'fps',
        'gid': 'gid',
        'height': 'height',
        'md5': 'md5',
        'media_files': 'media_files',
        'name': 'name',
        'num_frames': 'num_frames',
        'progress_name': 'progressName',
        'section': 'section',
        'thumbnail_gif_url': 'thumbnail_gif_url',
        'thumbnail_url': 'thumbnail_url',
        'type': 'type',
        'uid': 'uid',
        'width': 'width'
    }

    def __init__(self, codec=None, fps=None, gid=None, height=None, md5=None, media_files=None, name=None, num_frames=None, progress_name=None, section=None, thumbnail_gif_url=None, thumbnail_url=None, type=None, uid=None, width=None, local_vars_configuration=None):  # noqa: E501
        """VideoSpec - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._codec = None
        self._fps = None
        self._gid = None
        self._height = None
        self._md5 = None
        self._media_files = None
        self._name = None
        self._num_frames = None
        self._progress_name = None
        self._section = None
        self._thumbnail_gif_url = None
        self._thumbnail_url = None
        self._type = None
        self._uid = None
        self._width = None
        self.discriminator = None

        self.codec = codec
        self.fps = fps
        self.gid = gid
        self.height = height
        self.md5 = md5
        self.media_files = media_files
        self.name = name
        self.num_frames = num_frames
        if progress_name is not None:
            self.progress_name = progress_name
        self.section = section
        self.thumbnail_gif_url = thumbnail_gif_url
        self.thumbnail_url = thumbnail_url
        self.type = type
        self.uid = uid
        self.width = width

    @property
    def codec(self):
        """Gets the codec of this VideoSpec.  # noqa: E501

        Codec of the original video.  # noqa: E501

        :return: The codec of this VideoSpec.  # noqa: E501
        :rtype: str
        """
        return self._codec

    @codec.setter
    def codec(self, codec):
        """Sets the codec of this VideoSpec.

        Codec of the original video.  # noqa: E501

        :param codec: The codec of this VideoSpec.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and codec is None:  # noqa: E501
            raise ValueError("Invalid value for `codec`, must not be `None`")  # noqa: E501

        self._codec = codec

    @property
    def fps(self):
        """Gets the fps of this VideoSpec.  # noqa: E501

        Frame rate of the video.  # noqa: E501

        :return: The fps of this VideoSpec.  # noqa: E501
        :rtype: float
        """
        return self._fps

    @fps.setter
    def fps(self, fps):
        """Sets the fps of this VideoSpec.

        Frame rate of the video.  # noqa: E501

        :param fps: The fps of this VideoSpec.  # noqa: E501
        :type: float
        """
        if self.local_vars_configuration.client_side_validation and fps is None:  # noqa: E501
            raise ValueError("Invalid value for `fps`, must not be `None`")  # noqa: E501

        self._fps = fps

    @property
    def gid(self):
        """Gets the gid of this VideoSpec.  # noqa: E501

        UUID generated for the job group. This value is returned in the response of the `AlgorithmLaunch` and `Transcode` endpoints.  # noqa: E501

        :return: The gid of this VideoSpec.  # noqa: E501
        :rtype: str
        """
        return self._gid

    @gid.setter
    def gid(self, gid):
        """Sets the gid of this VideoSpec.

        UUID generated for the job group. This value is returned in the response of the `AlgorithmLaunch` and `Transcode` endpoints.  # noqa: E501

        :param gid: The gid of this VideoSpec.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and gid is None:  # noqa: E501
            raise ValueError("Invalid value for `gid`, must not be `None`")  # noqa: E501

        self._gid = gid

    @property
    def height(self):
        """Gets the height of this VideoSpec.  # noqa: E501

        Pixel height of the video.  # noqa: E501

        :return: The height of this VideoSpec.  # noqa: E501
        :rtype: int
        """
        return self._height

    @height.setter
    def height(self, height):
        """Sets the height of this VideoSpec.

        Pixel height of the video.  # noqa: E501

        :param height: The height of this VideoSpec.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and height is None:  # noqa: E501
            raise ValueError("Invalid value for `height`, must not be `None`")  # noqa: E501

        self._height = height

    @property
    def md5(self):
        """Gets the md5 of this VideoSpec.  # noqa: E501

        MD5 sum of the media file.  # noqa: E501

        :return: The md5 of this VideoSpec.  # noqa: E501
        :rtype: str
        """
        return self._md5

    @md5.setter
    def md5(self, md5):
        """Sets the md5 of this VideoSpec.

        MD5 sum of the media file.  # noqa: E501

        :param md5: The md5 of this VideoSpec.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and md5 is None:  # noqa: E501
            raise ValueError("Invalid value for `md5`, must not be `None`")  # noqa: E501

        self._md5 = md5

    @property
    def media_files(self):
        """Gets the media_files of this VideoSpec.  # noqa: E501


        :return: The media_files of this VideoSpec.  # noqa: E501
        :rtype: MediaFiles
        """
        return self._media_files

    @media_files.setter
    def media_files(self, media_files):
        """Sets the media_files of this VideoSpec.


        :param media_files: The media_files of this VideoSpec.  # noqa: E501
        :type: MediaFiles
        """
        if self.local_vars_configuration.client_side_validation and media_files is None:  # noqa: E501
            raise ValueError("Invalid value for `media_files`, must not be `None`")  # noqa: E501

        self._media_files = media_files

    @property
    def name(self):
        """Gets the name of this VideoSpec.  # noqa: E501

        Name of the file.  # noqa: E501

        :return: The name of this VideoSpec.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this VideoSpec.

        Name of the file.  # noqa: E501

        :param name: The name of this VideoSpec.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def num_frames(self):
        """Gets the num_frames of this VideoSpec.  # noqa: E501

        Number of frames in the video.  # noqa: E501

        :return: The num_frames of this VideoSpec.  # noqa: E501
        :rtype: int
        """
        return self._num_frames

    @num_frames.setter
    def num_frames(self, num_frames):
        """Sets the num_frames of this VideoSpec.

        Number of frames in the video.  # noqa: E501

        :param num_frames: The num_frames of this VideoSpec.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and num_frames is None:  # noqa: E501
            raise ValueError("Invalid value for `num_frames`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                num_frames is not None and num_frames < 0):  # noqa: E501
            raise ValueError("Invalid value for `num_frames`, must be a value greater than or equal to `0`")  # noqa: E501

        self._num_frames = num_frames

    @property
    def progress_name(self):
        """Gets the progress_name of this VideoSpec.  # noqa: E501

        Name to use for progress update.  # noqa: E501

        :return: The progress_name of this VideoSpec.  # noqa: E501
        :rtype: str
        """
        return self._progress_name

    @progress_name.setter
    def progress_name(self, progress_name):
        """Sets the progress_name of this VideoSpec.

        Name to use for progress update.  # noqa: E501

        :param progress_name: The progress_name of this VideoSpec.  # noqa: E501
        :type: str
        """

        self._progress_name = progress_name

    @property
    def section(self):
        """Gets the section of this VideoSpec.  # noqa: E501

        Media section name.  # noqa: E501

        :return: The section of this VideoSpec.  # noqa: E501
        :rtype: str
        """
        return self._section

    @section.setter
    def section(self, section):
        """Sets the section of this VideoSpec.

        Media section name.  # noqa: E501

        :param section: The section of this VideoSpec.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and section is None:  # noqa: E501
            raise ValueError("Invalid value for `section`, must not be `None`")  # noqa: E501

        self._section = section

    @property
    def thumbnail_gif_url(self):
        """Gets the thumbnail_gif_url of this VideoSpec.  # noqa: E501

        Upload URL for the thumbnail gif.  # noqa: E501

        :return: The thumbnail_gif_url of this VideoSpec.  # noqa: E501
        :rtype: str
        """
        return self._thumbnail_gif_url

    @thumbnail_gif_url.setter
    def thumbnail_gif_url(self, thumbnail_gif_url):
        """Sets the thumbnail_gif_url of this VideoSpec.

        Upload URL for the thumbnail gif.  # noqa: E501

        :param thumbnail_gif_url: The thumbnail_gif_url of this VideoSpec.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and thumbnail_gif_url is None:  # noqa: E501
            raise ValueError("Invalid value for `thumbnail_gif_url`, must not be `None`")  # noqa: E501

        self._thumbnail_gif_url = thumbnail_gif_url

    @property
    def thumbnail_url(self):
        """Gets the thumbnail_url of this VideoSpec.  # noqa: E501

        Upload URL for the thumbnail.  # noqa: E501

        :return: The thumbnail_url of this VideoSpec.  # noqa: E501
        :rtype: str
        """
        return self._thumbnail_url

    @thumbnail_url.setter
    def thumbnail_url(self, thumbnail_url):
        """Sets the thumbnail_url of this VideoSpec.

        Upload URL for the thumbnail.  # noqa: E501

        :param thumbnail_url: The thumbnail_url of this VideoSpec.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and thumbnail_url is None:  # noqa: E501
            raise ValueError("Invalid value for `thumbnail_url`, must not be `None`")  # noqa: E501

        self._thumbnail_url = thumbnail_url

    @property
    def type(self):
        """Gets the type of this VideoSpec.  # noqa: E501

        Unique integer identifying a video type. Use -1 to automatically select the video type if only one video type exists in a project.  # noqa: E501

        :return: The type of this VideoSpec.  # noqa: E501
        :rtype: int
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this VideoSpec.

        Unique integer identifying a video type. Use -1 to automatically select the video type if only one video type exists in a project.  # noqa: E501

        :param type: The type of this VideoSpec.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and type is None:  # noqa: E501
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                type is not None and type < -1):  # noqa: E501
            raise ValueError("Invalid value for `type`, must be a value greater than or equal to `-1`")  # noqa: E501

        self._type = type

    @property
    def uid(self):
        """Gets the uid of this VideoSpec.  # noqa: E501

        UUID generated for the individual job. This value is returned in the response of the `AlgorithmLaunch` and `Transcode` endpoints.  # noqa: E501

        :return: The uid of this VideoSpec.  # noqa: E501
        :rtype: str
        """
        return self._uid

    @uid.setter
    def uid(self, uid):
        """Sets the uid of this VideoSpec.

        UUID generated for the individual job. This value is returned in the response of the `AlgorithmLaunch` and `Transcode` endpoints.  # noqa: E501

        :param uid: The uid of this VideoSpec.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and uid is None:  # noqa: E501
            raise ValueError("Invalid value for `uid`, must not be `None`")  # noqa: E501

        self._uid = uid

    @property
    def width(self):
        """Gets the width of this VideoSpec.  # noqa: E501

        Pixel width of the video.  # noqa: E501

        :return: The width of this VideoSpec.  # noqa: E501
        :rtype: int
        """
        return self._width

    @width.setter
    def width(self, width):
        """Sets the width of this VideoSpec.

        Pixel width of the video.  # noqa: E501

        :param width: The width of this VideoSpec.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and width is None:  # noqa: E501
            raise ValueError("Invalid value for `width`, must not be `None`")  # noqa: E501

        self._width = width

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, VideoSpec):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, VideoSpec):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Tator REST API

    Interface to the Tator backend.  # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from tator_openapi.configuration import Configuration


class MediaTypeSpec(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'attribute_types': 'list[AttributeType]',
        'default_volume': 'int',
        'description': 'str',
        'dtype': 'str',
        'file_format': 'str',
        'keep_original': 'bool',
        'name': 'str'
    }

    attribute_map = {
        'attribute_types': 'attribute_types',
        'default_volume': 'default_volume',
        'description': 'description',
        'dtype': 'dtype',
        'file_format': 'file_format',
        'keep_original': 'keep_original',
        'name': 'name'
    }

    def __init__(self, attribute_types=None, default_volume=None, description='', dtype=None, file_format=None, keep_original=True, name=None, local_vars_configuration=None):  # noqa: E501
        """MediaTypeSpec - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._attribute_types = None
        self._default_volume = None
        self._description = None
        self._dtype = None
        self._file_format = None
        self._keep_original = None
        self._name = None
        self.discriminator = None

        if attribute_types is not None:
            self.attribute_types = attribute_types
        if default_volume is not None:
            self.default_volume = default_volume
        if description is not None:
            self.description = description
        self.dtype = dtype
        if file_format is not None:
            self.file_format = file_format
        if keep_original is not None:
            self.keep_original = keep_original
        self.name = name

    @property
    def attribute_types(self):
        """Gets the attribute_types of this MediaTypeSpec.  # noqa: E501

        Attribute type definitions.  # noqa: E501

        :return: The attribute_types of this MediaTypeSpec.  # noqa: E501
        :rtype: list[AttributeType]
        """
        return self._attribute_types

    @attribute_types.setter
    def attribute_types(self, attribute_types):
        """Sets the attribute_types of this MediaTypeSpec.

        Attribute type definitions.  # noqa: E501

        :param attribute_types: The attribute_types of this MediaTypeSpec.  # noqa: E501
        :type: list[AttributeType]
        """

        self._attribute_types = attribute_types

    @property
    def default_volume(self):
        """Gets the default_volume of this MediaTypeSpec.  # noqa: E501

        Default audio volume for this media type.  # noqa: E501

        :return: The default_volume of this MediaTypeSpec.  # noqa: E501
        :rtype: int
        """
        return self._default_volume

    @default_volume.setter
    def default_volume(self, default_volume):
        """Sets the default_volume of this MediaTypeSpec.

        Default audio volume for this media type.  # noqa: E501

        :param default_volume: The default_volume of this MediaTypeSpec.  # noqa: E501
        :type: int
        """
        if (self.local_vars_configuration.client_side_validation and
                default_volume is not None and default_volume > 100):  # noqa: E501
            raise ValueError("Invalid value for `default_volume`, must be a value less than or equal to `100`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                default_volume is not None and default_volume < 0):  # noqa: E501
            raise ValueError("Invalid value for `default_volume`, must be a value greater than or equal to `0`")  # noqa: E501

        self._default_volume = default_volume

    @property
    def description(self):
        """Gets the description of this MediaTypeSpec.  # noqa: E501

        Description of the media type.  # noqa: E501

        :return: The description of this MediaTypeSpec.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this MediaTypeSpec.

        Description of the media type.  # noqa: E501

        :param description: The description of this MediaTypeSpec.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def dtype(self):
        """Gets the dtype of this MediaTypeSpec.  # noqa: E501

        Type of the media, image or video.  # noqa: E501

        :return: The dtype of this MediaTypeSpec.  # noqa: E501
        :rtype: str
        """
        return self._dtype

    @dtype.setter
    def dtype(self, dtype):
        """Sets the dtype of this MediaTypeSpec.

        Type of the media, image or video.  # noqa: E501

        :param dtype: The dtype of this MediaTypeSpec.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and dtype is None:  # noqa: E501
            raise ValueError("Invalid value for `dtype`, must not be `None`")  # noqa: E501
        allowed_values = ["image", "video"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and dtype not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `dtype` ({0}), must be one of {1}"  # noqa: E501
                .format(dtype, allowed_values)
            )

        self._dtype = dtype

    @property
    def file_format(self):
        """Gets the file_format of this MediaTypeSpec.  # noqa: E501

        File extension. If omitted, any recognized file extension for the given dtype is accepted for upload. Do not include a dot prefix.  # noqa: E501

        :return: The file_format of this MediaTypeSpec.  # noqa: E501
        :rtype: str
        """
        return self._file_format

    @file_format.setter
    def file_format(self, file_format):
        """Sets the file_format of this MediaTypeSpec.

        File extension. If omitted, any recognized file extension for the given dtype is accepted for upload. Do not include a dot prefix.  # noqa: E501

        :param file_format: The file_format of this MediaTypeSpec.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                file_format is not None and len(file_format) > 4):
            raise ValueError("Invalid value for `file_format`, length must be less than or equal to `4`")  # noqa: E501

        self._file_format = file_format

    @property
    def keep_original(self):
        """Gets the keep_original of this MediaTypeSpec.  # noqa: E501

        For video dtype, whether to keep the original video file for archival purposes after transcoding. If true, the originally uploaded file will be available for download, otherwise downloads will use the transcoded videos.  # noqa: E501

        :return: The keep_original of this MediaTypeSpec.  # noqa: E501
        :rtype: bool
        """
        return self._keep_original

    @keep_original.setter
    def keep_original(self, keep_original):
        """Sets the keep_original of this MediaTypeSpec.

        For video dtype, whether to keep the original video file for archival purposes after transcoding. If true, the originally uploaded file will be available for download, otherwise downloads will use the transcoded videos.  # noqa: E501

        :param keep_original: The keep_original of this MediaTypeSpec.  # noqa: E501
        :type: bool
        """

        self._keep_original = keep_original

    @property
    def name(self):
        """Gets the name of this MediaTypeSpec.  # noqa: E501

        Name of the media type.  # noqa: E501

        :return: The name of this MediaTypeSpec.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this MediaTypeSpec.

        Name of the media type.  # noqa: E501

        :param name: The name of this MediaTypeSpec.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MediaTypeSpec):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, MediaTypeSpec):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Tator REST API

    Interface to the Tator backend.  # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from tator_openapi.configuration import Configuration


class ProgressSpec(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'gid': 'str',
        'job_type': 'str',
        'media_ids': 'str',
        'message': 'str',
        'name': 'str',
        'progress': 'float',
        'section': 'str',
        'sections': 'str',
        'state': 'str',
        'swid': 'str',
        'uid': 'str'
    }

    attribute_map = {
        'gid': 'gid',
        'job_type': 'job_type',
        'media_ids': 'media_ids',
        'message': 'message',
        'name': 'name',
        'progress': 'progress',
        'section': 'section',
        'sections': 'sections',
        'state': 'state',
        'swid': 'swid',
        'uid': 'uid'
    }

    def __init__(self, gid=None, job_type=None, media_ids=None, message=None, name=None, progress=None, section=None, sections=None, state=None, swid=None, uid=None, local_vars_configuration=None):  # noqa: E501
        """ProgressSpec - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._gid = None
        self._job_type = None
        self._media_ids = None
        self._message = None
        self._name = None
        self._progress = None
        self._section = None
        self._sections = None
        self._state = None
        self._swid = None
        self._uid = None
        self.discriminator = None

        self.gid = gid
        self.job_type = job_type
        if media_ids is not None:
            self.media_ids = media_ids
        self.message = message
        self.name = name
        self.progress = progress
        if section is not None:
            self.section = section
        if sections is not None:
            self.sections = sections
        self.state = state
        if swid is not None:
            self.swid = swid
        self.uid = uid

    @property
    def gid(self):
        """Gets the gid of this ProgressSpec.  # noqa: E501

        UUID generated for the job group. This value is returned in the response of the `AlgorithmLaunch` and `Transcode` endpoints.  # noqa: E501

        :return: The gid of this ProgressSpec.  # noqa: E501
        :rtype: str
        """
        return self._gid

    @gid.setter
    def gid(self, gid):
        """Sets the gid of this ProgressSpec.

        UUID generated for the job group. This value is returned in the response of the `AlgorithmLaunch` and `Transcode` endpoints.  # noqa: E501

        :param gid: The gid of this ProgressSpec.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and gid is None:  # noqa: E501
            raise ValueError("Invalid value for `gid`, must not be `None`")  # noqa: E501

        self._gid = gid

    @property
    def job_type(self):
        """Gets the job_type of this ProgressSpec.  # noqa: E501

        Type of background job.  # noqa: E501

        :return: The job_type of this ProgressSpec.  # noqa: E501
        :rtype: str
        """
        return self._job_type

    @job_type.setter
    def job_type(self, job_type):
        """Sets the job_type of this ProgressSpec.

        Type of background job.  # noqa: E501

        :param job_type: The job_type of this ProgressSpec.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and job_type is None:  # noqa: E501
            raise ValueError("Invalid value for `job_type`, must not be `None`")  # noqa: E501
        allowed_values = ["upload", "download", "algorithm"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and job_type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `job_type` ({0}), must be one of {1}"  # noqa: E501
                .format(job_type, allowed_values)
            )

        self._job_type = job_type

    @property
    def media_ids(self):
        """Gets the media_ids of this ProgressSpec.  # noqa: E501

        Comma separated string of media ids, one for each media that this job applies to. Required only for `job_type` of `algorithm`.  # noqa: E501

        :return: The media_ids of this ProgressSpec.  # noqa: E501
        :rtype: str
        """
        return self._media_ids

    @media_ids.setter
    def media_ids(self, media_ids):
        """Sets the media_ids of this ProgressSpec.

        Comma separated string of media ids, one for each media that this job applies to. Required only for `job_type` of `algorithm`.  # noqa: E501

        :param media_ids: The media_ids of this ProgressSpec.  # noqa: E501
        :type: str
        """

        self._media_ids = media_ids

    @property
    def message(self):
        """Gets the message of this ProgressSpec.  # noqa: E501

        Progress message. This should be short to fit in the UI.  # noqa: E501

        :return: The message of this ProgressSpec.  # noqa: E501
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """Sets the message of this ProgressSpec.

        Progress message. This should be short to fit in the UI.  # noqa: E501

        :param message: The message of this ProgressSpec.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and message is None:  # noqa: E501
            raise ValueError("Invalid value for `message`, must not be `None`")  # noqa: E501

        self._message = message

    @property
    def name(self):
        """Gets the name of this ProgressSpec.  # noqa: E501

        Name of the job.  # noqa: E501

        :return: The name of this ProgressSpec.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ProgressSpec.

        Name of the job.  # noqa: E501

        :param name: The name of this ProgressSpec.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def progress(self):
        """Gets the progress of this ProgressSpec.  # noqa: E501

        Progress percent completion. This is used to display the progress bar associated with the job.  # noqa: E501

        :return: The progress of this ProgressSpec.  # noqa: E501
        :rtype: float
        """
        return self._progress

    @progress.setter
    def progress(self, progress):
        """Sets the progress of this ProgressSpec.

        Progress percent completion. This is used to display the progress bar associated with the job.  # noqa: E501

        :param progress: The progress of this ProgressSpec.  # noqa: E501
        :type: float
        """
        if self.local_vars_configuration.client_side_validation and progress is None:  # noqa: E501
            raise ValueError("Invalid value for `progress`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                progress is not None and progress > 100):  # noqa: E501
            raise ValueError("Invalid value for `progress`, must be a value less than or equal to `100`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                progress is not None and progress < 0):  # noqa: E501
            raise ValueError("Invalid value for `progress`, must be a value greater than or equal to `0`")  # noqa: E501

        self._progress = progress

    @property
    def section(self):
        """Gets the section of this ProgressSpec.  # noqa: E501

        Media section name. Required only for `job_type` of `upload`.  # noqa: E501

        :return: The section of this ProgressSpec.  # noqa: E501
        :rtype: str
        """
        return self._section

    @section.setter
    def section(self, section):
        """Sets the section of this ProgressSpec.

        Media section name. Required only for `job_type` of `upload`.  # noqa: E501

        :param section: The section of this ProgressSpec.  # noqa: E501
        :type: str
        """

        self._section = section

    @property
    def sections(self):
        """Gets the sections of this ProgressSpec.  # noqa: E501

        Comma separated string of media sections, one for each media ID that this job applies to. Required only for `job_type` of `algorithm`.  # noqa: E501

        :return: The sections of this ProgressSpec.  # noqa: E501
        :rtype: str
        """
        return self._sections

    @sections.setter
    def sections(self, sections):
        """Sets the sections of this ProgressSpec.

        Comma separated string of media sections, one for each media ID that this job applies to. Required only for `job_type` of `algorithm`.  # noqa: E501

        :param sections: The sections of this ProgressSpec.  # noqa: E501
        :type: str
        """

        self._sections = sections

    @property
    def state(self):
        """Gets the state of this ProgressSpec.  # noqa: E501

        State of the job.  # noqa: E501

        :return: The state of this ProgressSpec.  # noqa: E501
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this ProgressSpec.

        State of the job.  # noqa: E501

        :param state: The state of this ProgressSpec.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and state is None:  # noqa: E501
            raise ValueError("Invalid value for `state`, must not be `None`")  # noqa: E501
        allowed_values = ["queued", "started", "failed", "finished"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and state not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `state` ({0}), must be one of {1}"  # noqa: E501
                .format(state, allowed_values)
            )

        self._state = state

    @property
    def swid(self):
        """Gets the swid of this ProgressSpec.  # noqa: E501

        UUID generated for the service worker that is doing an upload. This field is required if the `job_type` is `upload`.  # noqa: E501

        :return: The swid of this ProgressSpec.  # noqa: E501
        :rtype: str
        """
        return self._swid

    @swid.setter
    def swid(self, swid):
        """Sets the swid of this ProgressSpec.

        UUID generated for the service worker that is doing an upload. This field is required if the `job_type` is `upload`.  # noqa: E501

        :param swid: The swid of this ProgressSpec.  # noqa: E501
        :type: str
        """

        self._swid = swid

    @property
    def uid(self):
        """Gets the uid of this ProgressSpec.  # noqa: E501

        UUID generated for the individual job. This value is returned in the response of the `AlgorithmLaunch` and `Transcode` endpoints.  # noqa: E501

        :return: The uid of this ProgressSpec.  # noqa: E501
        :rtype: str
        """
        return self._uid

    @uid.setter
    def uid(self, uid):
        """Sets the uid of this ProgressSpec.

        UUID generated for the individual job. This value is returned in the response of the `AlgorithmLaunch` and `Transcode` endpoints.  # noqa: E501

        :param uid: The uid of this ProgressSpec.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and uid is None:  # noqa: E501
            raise ValueError("Invalid value for `uid`, must not be `None`")  # noqa: E501

        self._uid = uid

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ProgressSpec):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ProgressSpec):
            return True

        return self.to_dict() != other.to_dict()



def to_dataframe(objects):
    """ Converts list of objects to :class:`pandas.DataFrame`.

    :param object: List of objects.
    :returns: Pandas dataframe.
    """
    try:
        import pandas as pd
    except:
        raise RuntimeError("Utility to_dataframe requires pandas to be installed: `pip install pandas`")
    out = None
    if objects:
        dict_objects = [obj.to_dict() for obj in objects]
        out = pd.DataFrame(data=dict_objects,
                           columns=dict_objects[0].keys())
    return out



import tator

def get_images(file_path, media_or_state, num_images=None, width=None, height=None):
    """ Loads image saved by :meth:`tator.TatorApi.get_frame` or 
        :meth:`tator.TatorApi.get_state_graphic` into a list of
        :class:`PIL.Image.Image`.

    :param file_path: Path to image file.
    :param media_or_state: :class:`tator.Media` or :class:`tator.State` object.
    :param num_images: [Optional] The number of images to unwrap if this
        is an image saved by :meth:`tator.TatorApi.get_frame`.
    :param width: [Optional] Width of ROI if this is an image saved by 
        :meth:`tator.TatorApi.get_frame`.
    :param height: [Optional] Height of ROI if this is an image saved by 
        :meth:`tator.TatorApi.get_frame`.
    """
    try:
        from PIL import Image
    except:
        raise RuntimeError("Utility get_images requires pillow to be installed: `pip install pillow`")
    # Read in raw image.
    img = Image.open(file_path)

    # Get tile width/height.
    if isinstance(media_or_state, tator.State):
        num_localizations = len(media_or_state.localizations)
        width = int(img.width / num_localizations)
        height = img.height
    elif isinstance(media_or_state, tator.Media):
        if width is None:
            width = media_or_state.width
        if height is None:
            height = media_or_state.height
    
    # Make list of crops.
    images = []
    for top in range(0, img.height, height):
        for left in range(0, img.width, width):
            image = img.crop((left, top, left+width, top+height))
            images.append(image)
    if num_images:
        images = images[:num_images]
    return images



from uuid import uuid1
import mimetypes
import os
import math

from tusclient.client import TusClient
from urllib.parse import urljoin
from urllib.parse import urlsplit

from .md5sum import md5sum

def upload_media(api, type_id, path, md5=None, section=None, fname=None,
                 upload_gid=None, upload_uid=None, chunk_size=2*1024*1024):
    """ Uploads a single media file.

    Example:
    .. highlight:: python
    .. code-block:: python
        api = tator.get_api(host, token)
        for progress, response in tator.upload_media(api, type_id, path):
            print(f"Upload progress: {progress}%")
        print(response.message)

    :param api: :class:`tator.TatorApi` object.
    :param type_id: Unique integer identifying a media type.
    :param path: Path to the media file.
    :param md5: [Optional] md5 sum of the media.
    :param section: [Optional] Media section to upload to.
    :param fname: [Optional] Filename to use for upload.
    :param upload_gid: [Optional] Group ID of the upload.
    :param upload_uid: [Optional] Unique ID of the upload.
    :param chunk_size: [Optional] Chunk size in bytes. Default is 2MB.
    :returns: Generator that yields tuple containing progress (0-100) and a
        response. The response is `None` until the last yield, when the response
        is the response object from :meth:`tator.TatorApi.save_video` or 
        :meth:`tator.TatorApi.transcode`.
    """
    if md5==None:
        md5 = md5sum(path)
    if upload_uid is None:
        upload_uid = str(uuid1())
    if upload_gid is None:
        upload_gid = str(uuid1())
    if fname is None:
        fname=os.path.basename(path)
    if section is None:
        section="New Files"

    host = api.api_client.configuration.host
    tusURL = urljoin(host, "files/")
    tus = TusClient(tusURL)
    uploader = tus.uploader(path, chunk_size=chunk_size,
                            retries=10, retry_delay=15)
    num_chunks=math.ceil(uploader.get_file_size()/chunk_size)

    last_progress = 0
    yield (last_progress, None)

    for chunk_count in range(num_chunks):
        uploader.upload_chunk()
        this_progress = round((chunk_count / num_chunks) *100,1)
        if this_progress != last_progress:
            yield (this_progress, None)
            last_progress = this_progress

    mime,_ = mimetypes.guess_type(fname)
    response = api.get_media_type(type_id)
    project_id = response.project
    spec = {
        'type': type_id,
        'uid': upload_uid,
        'gid': upload_gid,
        'url': uploader.url,
        'name': fname,
        'section': section,
        'md5': md5,
    }
    # Initiate transcode or save image.
    if mime.find('video') >= 0:
        response = api.transcode(project_id, transcode_spec=spec)
    else:
        response = api.save_image(project_id, image_spec=spec)
    yield (100, response)



import os

import tator

def test_upload_archive(host, token, project, image_type, image_set):
    tator_api = tator.get_api(host, token)
    paths = os.listdir(image_set)
    paths = [os.path.join(image_set, path) for path in paths]
    paths = paths[:1000] # Only upload the first 1000 files.
    batch_num = 0
    for batch in tator.chunked_file_list(paths):
        print(f"Uploading file {batch_num*100} / {len(paths)}")
        for progress, response in tator.upload_media_archive(tator_api, project, batch):
            print(f"Archive upload progress: {progress}%")
        batch_num += 1
        assert isinstance(response, tator.Transcode)
        print(response.message)
    



# coding: utf-8

"""
    Tator REST API

    Interface to the Tator backend.  # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from tator_openapi.configuration import Configuration


class StateTypeSpec(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'association': 'str',
        'attribute_types': 'list[AttributeType]',
        'description': 'str',
        'media_types': 'list[int]',
        'name': 'str'
    }

    attribute_map = {
        'association': 'association',
        'attribute_types': 'attribute_types',
        'description': 'description',
        'media_types': 'media_types',
        'name': 'name'
    }

    def __init__(self, association=None, attribute_types=None, description=None, media_types=None, name=None, local_vars_configuration=None):  # noqa: E501
        """StateTypeSpec - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._association = None
        self._attribute_types = None
        self._description = None
        self._media_types = None
        self._name = None
        self.discriminator = None

        self.association = association
        if attribute_types is not None:
            self.attribute_types = attribute_types
        if description is not None:
            self.description = description
        self.media_types = media_types
        self.name = name

    @property
    def association(self):
        """Gets the association of this StateTypeSpec.  # noqa: E501

        Type of object this state type is associated with.  # noqa: E501

        :return: The association of this StateTypeSpec.  # noqa: E501
        :rtype: str
        """
        return self._association

    @association.setter
    def association(self, association):
        """Sets the association of this StateTypeSpec.

        Type of object this state type is associated with.  # noqa: E501

        :param association: The association of this StateTypeSpec.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and association is None:  # noqa: E501
            raise ValueError("Invalid value for `association`, must not be `None`")  # noqa: E501
        allowed_values = ["Media", "Frame", "Localization"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and association not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `association` ({0}), must be one of {1}"  # noqa: E501
                .format(association, allowed_values)
            )

        self._association = association

    @property
    def attribute_types(self):
        """Gets the attribute_types of this StateTypeSpec.  # noqa: E501

        Attribute type definitions.  # noqa: E501

        :return: The attribute_types of this StateTypeSpec.  # noqa: E501
        :rtype: list[AttributeType]
        """
        return self._attribute_types

    @attribute_types.setter
    def attribute_types(self, attribute_types):
        """Sets the attribute_types of this StateTypeSpec.

        Attribute type definitions.  # noqa: E501

        :param attribute_types: The attribute_types of this StateTypeSpec.  # noqa: E501
        :type: list[AttributeType]
        """

        self._attribute_types = attribute_types

    @property
    def description(self):
        """Gets the description of this StateTypeSpec.  # noqa: E501

        Description of the state type.  # noqa: E501

        :return: The description of this StateTypeSpec.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this StateTypeSpec.

        Description of the state type.  # noqa: E501

        :param description: The description of this StateTypeSpec.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def media_types(self):
        """Gets the media_types of this StateTypeSpec.  # noqa: E501

        List of integers identifying media types that this state type may apply to.  # noqa: E501

        :return: The media_types of this StateTypeSpec.  # noqa: E501
        :rtype: list[int]
        """
        return self._media_types

    @media_types.setter
    def media_types(self, media_types):
        """Sets the media_types of this StateTypeSpec.

        List of integers identifying media types that this state type may apply to.  # noqa: E501

        :param media_types: The media_types of this StateTypeSpec.  # noqa: E501
        :type: list[int]
        """
        if self.local_vars_configuration.client_side_validation and media_types is None:  # noqa: E501
            raise ValueError("Invalid value for `media_types`, must not be `None`")  # noqa: E501

        self._media_types = media_types

    @property
    def name(self):
        """Gets the name of this StateTypeSpec.  # noqa: E501

        Name of the state type.  # noqa: E501

        :return: The name of this StateTypeSpec.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this StateTypeSpec.

        Name of the state type.  # noqa: E501

        :param name: The name of this StateTypeSpec.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, StateTypeSpec):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, StateTypeSpec):
            return True

        return self.to_dict() != other.to_dict()



import hashlib

def md5sum(fname):
    """ Computes md5 sum of a file contents.

    :param fname: Path to file.
    :returns: md5 sum of the file.
    """
    md5 = hashlib.md5()
    with open(fname, 'rb') as f:
        for chunk in iter(lambda: f.read(128*md5.block_size), b''):
            md5.update(chunk)
    return md5.hexdigest()



import os
import math

import requests
from urllib.parse import urljoin
from urllib.parse import urlsplit

def download_media(api, media, out_path):
    """ Download a media file from Tator to an off-line location.

    Example:
    .. highlight:: python
    .. code-block:: python
        api = tator.get_api(host, token)
        media = api.get_media(media_id)
        out_path = f'/tmp/{media.name}'
        for progress in tator.download_media(api, media, out_path):
            print(f"Download progress: {progress}%")

    :param api: :class:`tator.TatorApi` object.
    :param media: :class:`tator.Media` object.
    :param path-like out_path: Path to where to download.
    :returns: Generator the yields progress (0-100).
    """
    config = api.api_client.configuration
    host = config.host
    token = config.api_key['Authorization']
    prefix = config.api_key_prefix['Authorization']
    if media.media_files is not None:
        archival = media.media_files.archival
        streaming = media.media_files.streaming
        if len(archival) > 0:
            url = urljoin(host, archival[0].path)
        elif len(streaming) > 0:
            url = urljoin(host, streaming[0].path)
    else:
        # Legacy way of using streaming prior to streaming
        url = os.path.join("media", media.file)
        if media.original:
            url = os.path.join("data/raw", media.original)
        url = urljoin(host, url)

    # Supply token here for eventual media authorization
    headers = {
        'Authorization': f'{prefix} {token}',
        'Content-Type': f'application/json',
        'Accept-Encoding': 'gzip',
    }
    with requests.get(url, stream=True, headers=headers) as r:
        r.raise_for_status()
        total_size = r.headers['Content-Length']
        total_chunks = math.ceil(int(total_size) / 8192)
        chunk_count = 0
        last_progress = 0
        yield last_progress
        with open(out_path, 'wb') as f:
            for chunk in r.iter_content(chunk_size=8192):
                if chunk:
                    chunk_count += 1
                    f.write(chunk)
                    this_progress = round((chunk_count / total_chunks) *100,1)
                    if this_progress != last_progress:
                        yield this_progress
                        last_progress = this_progress
        yield 100



def chunked_file_list(paths, chunk_size=100):
    """ Breaks file list into chunks for upload via media archive.

    Example:
    .. highlight:: python
    .. code-block:: python
        api = tator.get_api(host, token)
        batch_num = 0
        for batch in tator.chunked_file_list(paths):
            print(f"Uploading file {batch_num*100} / {len(paths)}")
            for progress, response in tator.upload_media_archive(api, project_id, batch):
                print(f"Upload progress: {progress}%")
            print(response.message)
            batch_num += 1

    :param paths: List of file paths.
    :param chunk_size: [Optional] Size of batches for file upload. Archive uploads are created in
        memory, so this should be set to a reasonable value based on file size. Default
        is 100.
    :returns: Generator that yields batches of file paths.
    """
    for idx in range(0, len(paths), chunk_size):
        yield paths[idx:idx+chunk_size]



# coding: utf-8

"""
    Tator REST API

    Interface to the Tator backend.  # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from tator_openapi.configuration import Configuration


class ProgressSummarySpec(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'gid': 'str',
        'num_complete': 'int',
        'num_jobs': 'int'
    }

    attribute_map = {
        'gid': 'gid',
        'num_complete': 'num_complete',
        'num_jobs': 'num_jobs'
    }

    def __init__(self, gid=None, num_complete=None, num_jobs=None, local_vars_configuration=None):  # noqa: E501
        """ProgressSummarySpec - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._gid = None
        self._num_complete = None
        self._num_jobs = None
        self.discriminator = None

        self.gid = gid
        self.num_complete = num_complete
        self.num_jobs = num_jobs

    @property
    def gid(self):
        """Gets the gid of this ProgressSummarySpec.  # noqa: E501

        UUID generated for the job group. This value is returned in the response of the `AlgorithmLaunch` and `Transcode` endpoints.  # noqa: E501

        :return: The gid of this ProgressSummarySpec.  # noqa: E501
        :rtype: str
        """
        return self._gid

    @gid.setter
    def gid(self, gid):
        """Sets the gid of this ProgressSummarySpec.

        UUID generated for the job group. This value is returned in the response of the `AlgorithmLaunch` and `Transcode` endpoints.  # noqa: E501

        :param gid: The gid of this ProgressSummarySpec.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and gid is None:  # noqa: E501
            raise ValueError("Invalid value for `gid`, must not be `None`")  # noqa: E501

        self._gid = gid

    @property
    def num_complete(self):
        """Gets the num_complete of this ProgressSummarySpec.  # noqa: E501

        Number of jobs completed in this job group.  # noqa: E501

        :return: The num_complete of this ProgressSummarySpec.  # noqa: E501
        :rtype: int
        """
        return self._num_complete

    @num_complete.setter
    def num_complete(self, num_complete):
        """Sets the num_complete of this ProgressSummarySpec.

        Number of jobs completed in this job group.  # noqa: E501

        :param num_complete: The num_complete of this ProgressSummarySpec.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and num_complete is None:  # noqa: E501
            raise ValueError("Invalid value for `num_complete`, must not be `None`")  # noqa: E501

        self._num_complete = num_complete

    @property
    def num_jobs(self):
        """Gets the num_jobs of this ProgressSummarySpec.  # noqa: E501

        Number of jobs in this job group.  # noqa: E501

        :return: The num_jobs of this ProgressSummarySpec.  # noqa: E501
        :rtype: int
        """
        return self._num_jobs

    @num_jobs.setter
    def num_jobs(self, num_jobs):
        """Sets the num_jobs of this ProgressSummarySpec.

        Number of jobs in this job group.  # noqa: E501

        :param num_jobs: The num_jobs of this ProgressSummarySpec.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and num_jobs is None:  # noqa: E501
            raise ValueError("Invalid value for `num_jobs`, must not be `None`")  # noqa: E501

        self._num_jobs = num_jobs

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ProgressSummarySpec):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ProgressSummarySpec):
            return True

        return self.to_dict() != other.to_dict()



import argparse

def get_parser():
    """ Returns an argument parser that includes host and token.

    :returns: :class:`argparse.ArgumentParser` object that includes host and token arguments.
    """
    parser = argparse.ArgumentParser(description="Creates a test project.")
    parser.add_argument('--host', default='https://www.tatorapp.com')
    parser.add_argument('--token', help="Your API token.")
    return parser



# coding: utf-8

# flake8: noqa

"""
    Tator REST API

    Interface to the Tator backend.  # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

__version__ = "0.0.14"

# import apis into sdk package
from tator_openapi.api.tator_api import TatorApi

# import ApiClient
from tator_openapi.api_client import ApiClient
from tator_openapi.configuration import Configuration
from tator_openapi.exceptions import OpenApiException
from tator_openapi.exceptions import ApiTypeError
from tator_openapi.exceptions import ApiValueError
from tator_openapi.exceptions import ApiKeyError
from tator_openapi.exceptions import ApiException
# import models into sdk package
from tator_openapi.models.algorithm import Algorithm
from tator_openapi.models.algorithm_launch import AlgorithmLaunch
from tator_openapi.models.algorithm_launch_spec import AlgorithmLaunchSpec
from tator_openapi.models.analysis import Analysis
from tator_openapi.models.analysis_spec import AnalysisSpec
from tator_openapi.models.attribute_bulk_update import AttributeBulkUpdate
from tator_openapi.models.attribute_type import AttributeType
from tator_openapi.models.audio_definition import AudioDefinition
from tator_openapi.models.autocomplete_service import AutocompleteService
from tator_openapi.models.bad_request_response import BadRequestResponse
from tator_openapi.models.color_map import ColorMap
from tator_openapi.models.create_list_response import CreateListResponse
from tator_openapi.models.create_response import CreateResponse
from tator_openapi.models.credentials import Credentials
from tator_openapi.models.image_spec import ImageSpec
from tator_openapi.models.leaf import Leaf
from tator_openapi.models.leaf_spec import LeafSpec
from tator_openapi.models.leaf_suggestion import LeafSuggestion
from tator_openapi.models.leaf_type import LeafType
from tator_openapi.models.leaf_type_spec import LeafTypeSpec
from tator_openapi.models.leaf_type_update import LeafTypeUpdate
from tator_openapi.models.leaf_update import LeafUpdate
from tator_openapi.models.localization import Localization
from tator_openapi.models.localization_spec import LocalizationSpec
from tator_openapi.models.localization_type import LocalizationType
from tator_openapi.models.localization_type_spec import LocalizationTypeSpec
from tator_openapi.models.localization_type_update import LocalizationTypeUpdate
from tator_openapi.models.localization_update import LocalizationUpdate
from tator_openapi.models.media import Media
from tator_openapi.models.media_files import MediaFiles
from tator_openapi.models.media_next import MediaNext
from tator_openapi.models.media_prev import MediaPrev
from tator_openapi.models.media_type import MediaType
from tator_openapi.models.media_type_spec import MediaTypeSpec
from tator_openapi.models.media_type_update import MediaTypeUpdate
from tator_openapi.models.media_update import MediaUpdate
from tator_openapi.models.membership import Membership
from tator_openapi.models.membership_spec import MembershipSpec
from tator_openapi.models.membership_update import MembershipUpdate
from tator_openapi.models.message_response import MessageResponse
from tator_openapi.models.not_found_response import NotFoundResponse
from tator_openapi.models.notify_spec import NotifySpec
from tator_openapi.models.progress_spec import ProgressSpec
from tator_openapi.models.progress_summary_spec import ProgressSummarySpec
from tator_openapi.models.project import Project
from tator_openapi.models.project_spec import ProjectSpec
from tator_openapi.models.state import State
from tator_openapi.models.state_spec import StateSpec
from tator_openapi.models.state_type import StateType
from tator_openapi.models.state_type_spec import StateTypeSpec
from tator_openapi.models.state_type_update import StateTypeUpdate
from tator_openapi.models.state_update import StateUpdate
from tator_openapi.models.temporary_file import TemporaryFile
from tator_openapi.models.temporary_file_spec import TemporaryFileSpec
from tator_openapi.models.token import Token
from tator_openapi.models.transcode import Transcode
from tator_openapi.models.transcode_spec import TranscodeSpec
from tator_openapi.models.user import User
from tator_openapi.models.user_update import UserUpdate
from tator_openapi.models.version import Version
from tator_openapi.models.version_spec import VersionSpec
from tator_openapi.models.version_update import VersionUpdate
from tator_openapi.models.video_definition import VideoDefinition
from tator_openapi.models.video_spec import VideoSpec
from tator_openapi.models.video_update import VideoUpdate




import tator

from ._common import assert_vector_equal

def test_get_frame(host, token, project, video):
    tator_api = tator.get_api(host, token)
    video_obj = tator_api.get_media(video)

    frames = [50,100,150]
    file_path = tator_api.get_frame(video, frames=frames)
    frame_bgr = tator.get_images(file_path, video_obj)

    assert(len(frame_bgr) == 4)
    for frame_data in frame_bgr:
        size = (frame_data.height, frame_data.width, len(frame_data.mode))
        assert_vector_equal(size, (720,1280,3))
    




# coding: utf-8

"""
    Tator REST API

    Interface to the Tator backend.  # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from tator_openapi.configuration import Configuration


class Localization(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'attributes': 'dict(str, object)',
        'email': 'str',
        'frame': 'int',
        'height': 'float',
        'id': 'int',
        'media': 'int',
        'meta': 'int',
        'modified': 'bool',
        'parent': 'float',
        'project': 'int',
        'thumbnail_image': 'str',
        'u': 'float',
        'v': 'float',
        'version': 'int',
        'width': 'float',
        'x': 'float',
        'y': 'float'
    }

    attribute_map = {
        'attributes': 'attributes',
        'email': 'email',
        'frame': 'frame',
        'height': 'height',
        'id': 'id',
        'media': 'media',
        'meta': 'meta',
        'modified': 'modified',
        'parent': 'parent',
        'project': 'project',
        'thumbnail_image': 'thumbnail_image',
        'u': 'u',
        'v': 'v',
        'version': 'version',
        'width': 'width',
        'x': 'x',
        'y': 'y'
    }

    def __init__(self, attributes=None, email=None, frame=None, height=None, id=None, media=None, meta=None, modified=None, parent=None, project=None, thumbnail_image=None, u=None, v=None, version=None, width=None, x=None, y=None, local_vars_configuration=None):  # noqa: E501
        """Localization - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._attributes = None
        self._email = None
        self._frame = None
        self._height = None
        self._id = None
        self._media = None
        self._meta = None
        self._modified = None
        self._parent = None
        self._project = None
        self._thumbnail_image = None
        self._u = None
        self._v = None
        self._version = None
        self._width = None
        self._x = None
        self._y = None
        self.discriminator = None

        if attributes is not None:
            self.attributes = attributes
        if email is not None:
            self.email = email
        if frame is not None:
            self.frame = frame
        self.height = height
        if id is not None:
            self.id = id
        if media is not None:
            self.media = media
        if meta is not None:
            self.meta = meta
        if modified is not None:
            self.modified = modified
        self.parent = parent
        if project is not None:
            self.project = project
        if thumbnail_image is not None:
            self.thumbnail_image = thumbnail_image
        self.u = u
        self.v = v
        if version is not None:
            self.version = version
        self.width = width
        self.x = x
        self.y = y

    @property
    def attributes(self):
        """Gets the attributes of this Localization.  # noqa: E501

        Object containing attribute values.  # noqa: E501

        :return: The attributes of this Localization.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._attributes

    @attributes.setter
    def attributes(self, attributes):
        """Sets the attributes of this Localization.

        Object containing attribute values.  # noqa: E501

        :param attributes: The attributes of this Localization.  # noqa: E501
        :type: dict(str, object)
        """

        self._attributes = attributes

    @property
    def email(self):
        """Gets the email of this Localization.  # noqa: E501

        Email of last user who modified/created this localization.  # noqa: E501

        :return: The email of this Localization.  # noqa: E501
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this Localization.

        Email of last user who modified/created this localization.  # noqa: E501

        :param email: The email of this Localization.  # noqa: E501
        :type: str
        """

        self._email = email

    @property
    def frame(self):
        """Gets the frame of this Localization.  # noqa: E501

        Frame number of this localization if it is in a video.  # noqa: E501

        :return: The frame of this Localization.  # noqa: E501
        :rtype: int
        """
        return self._frame

    @frame.setter
    def frame(self, frame):
        """Sets the frame of this Localization.

        Frame number of this localization if it is in a video.  # noqa: E501

        :param frame: The frame of this Localization.  # noqa: E501
        :type: int
        """

        self._frame = frame

    @property
    def height(self):
        """Gets the height of this Localization.  # noqa: E501

        Normalized height of bounding box for `box` localization types.  # noqa: E501

        :return: The height of this Localization.  # noqa: E501
        :rtype: float
        """
        return self._height

    @height.setter
    def height(self, height):
        """Sets the height of this Localization.

        Normalized height of bounding box for `box` localization types.  # noqa: E501

        :param height: The height of this Localization.  # noqa: E501
        :type: float
        """
        if (self.local_vars_configuration.client_side_validation and
                height is not None and height > 1.0):  # noqa: E501
            raise ValueError("Invalid value for `height`, must be a value less than or equal to `1.0`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                height is not None and height < 0.0):  # noqa: E501
            raise ValueError("Invalid value for `height`, must be a value greater than or equal to `0.0`")  # noqa: E501

        self._height = height

    @property
    def id(self):
        """Gets the id of this Localization.  # noqa: E501

        Unique integer identifying this localization.  # noqa: E501

        :return: The id of this Localization.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Localization.

        Unique integer identifying this localization.  # noqa: E501

        :param id: The id of this Localization.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def media(self):
        """Gets the media of this Localization.  # noqa: E501

        Unique integer identifying media of this localization.  # noqa: E501

        :return: The media of this Localization.  # noqa: E501
        :rtype: int
        """
        return self._media

    @media.setter
    def media(self, media):
        """Sets the media of this Localization.

        Unique integer identifying media of this localization.  # noqa: E501

        :param media: The media of this Localization.  # noqa: E501
        :type: int
        """

        self._media = media

    @property
    def meta(self):
        """Gets the meta of this Localization.  # noqa: E501

        Unique integer identifying entity type of this localization.  # noqa: E501

        :return: The meta of this Localization.  # noqa: E501
        :rtype: int
        """
        return self._meta

    @meta.setter
    def meta(self, meta):
        """Sets the meta of this Localization.

        Unique integer identifying entity type of this localization.  # noqa: E501

        :param meta: The meta of this Localization.  # noqa: E501
        :type: int
        """

        self._meta = meta

    @property
    def modified(self):
        """Gets the modified of this Localization.  # noqa: E501

        Indicates whether this localization has been modified in the web UI.  # noqa: E501

        :return: The modified of this Localization.  # noqa: E501
        :rtype: bool
        """
        return self._modified

    @modified.setter
    def modified(self, modified):
        """Sets the modified of this Localization.

        Indicates whether this localization has been modified in the web UI.  # noqa: E501

        :param modified: The modified of this Localization.  # noqa: E501
        :type: bool
        """

        self._modified = modified

    @property
    def parent(self):
        """Gets the parent of this Localization.  # noqa: E501

        If a clone, the pk of the parent.  # noqa: E501

        :return: The parent of this Localization.  # noqa: E501
        :rtype: float
        """
        return self._parent

    @parent.setter
    def parent(self, parent):
        """Sets the parent of this Localization.

        If a clone, the pk of the parent.  # noqa: E501

        :param parent: The parent of this Localization.  # noqa: E501
        :type: float
        """

        self._parent = parent

    @property
    def project(self):
        """Gets the project of this Localization.  # noqa: E501

        Unique integer identifying project of this localization.  # noqa: E501

        :return: The project of this Localization.  # noqa: E501
        :rtype: int
        """
        return self._project

    @project.setter
    def project(self, project):
        """Sets the project of this Localization.

        Unique integer identifying project of this localization.  # noqa: E501

        :param project: The project of this Localization.  # noqa: E501
        :type: int
        """

        self._project = project

    @property
    def thumbnail_image(self):
        """Gets the thumbnail_image of this Localization.  # noqa: E501

        URL of thumbnail corresponding to this localization.  # noqa: E501

        :return: The thumbnail_image of this Localization.  # noqa: E501
        :rtype: str
        """
        return self._thumbnail_image

    @thumbnail_image.setter
    def thumbnail_image(self, thumbnail_image):
        """Sets the thumbnail_image of this Localization.

        URL of thumbnail corresponding to this localization.  # noqa: E501

        :param thumbnail_image: The thumbnail_image of this Localization.  # noqa: E501
        :type: str
        """

        self._thumbnail_image = thumbnail_image

    @property
    def u(self):
        """Gets the u of this Localization.  # noqa: E501

        Horizontal vector component for `line` localization types.  # noqa: E501

        :return: The u of this Localization.  # noqa: E501
        :rtype: float
        """
        return self._u

    @u.setter
    def u(self, u):
        """Sets the u of this Localization.

        Horizontal vector component for `line` localization types.  # noqa: E501

        :param u: The u of this Localization.  # noqa: E501
        :type: float
        """
        if (self.local_vars_configuration.client_side_validation and
                u is not None and u > 1.0):  # noqa: E501
            raise ValueError("Invalid value for `u`, must be a value less than or equal to `1.0`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                u is not None and u < -1.0):  # noqa: E501
            raise ValueError("Invalid value for `u`, must be a value greater than or equal to `-1.0`")  # noqa: E501

        self._u = u

    @property
    def v(self):
        """Gets the v of this Localization.  # noqa: E501

        Vertical vector component for `line` localization types.  # noqa: E501

        :return: The v of this Localization.  # noqa: E501
        :rtype: float
        """
        return self._v

    @v.setter
    def v(self, v):
        """Sets the v of this Localization.

        Vertical vector component for `line` localization types.  # noqa: E501

        :param v: The v of this Localization.  # noqa: E501
        :type: float
        """
        if (self.local_vars_configuration.client_side_validation and
                v is not None and v > 1.0):  # noqa: E501
            raise ValueError("Invalid value for `v`, must be a value less than or equal to `1.0`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                v is not None and v < -1.0):  # noqa: E501
            raise ValueError("Invalid value for `v`, must be a value greater than or equal to `-1.0`")  # noqa: E501

        self._v = v

    @property
    def version(self):
        """Gets the version of this Localization.  # noqa: E501

        Unique integer identifying a version.  # noqa: E501

        :return: The version of this Localization.  # noqa: E501
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this Localization.

        Unique integer identifying a version.  # noqa: E501

        :param version: The version of this Localization.  # noqa: E501
        :type: int
        """

        self._version = version

    @property
    def width(self):
        """Gets the width of this Localization.  # noqa: E501

        Normalized width of bounding box for `box` localization types.  # noqa: E501

        :return: The width of this Localization.  # noqa: E501
        :rtype: float
        """
        return self._width

    @width.setter
    def width(self, width):
        """Sets the width of this Localization.

        Normalized width of bounding box for `box` localization types.  # noqa: E501

        :param width: The width of this Localization.  # noqa: E501
        :type: float
        """
        if (self.local_vars_configuration.client_side_validation and
                width is not None and width > 1.0):  # noqa: E501
            raise ValueError("Invalid value for `width`, must be a value less than or equal to `1.0`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                width is not None and width < 0.0):  # noqa: E501
            raise ValueError("Invalid value for `width`, must be a value greater than or equal to `0.0`")  # noqa: E501

        self._width = width

    @property
    def x(self):
        """Gets the x of this Localization.  # noqa: E501

        Normalized horizontal position of left edge of bounding box for `box` localization types, start of line for `line` localization types, or position of dot for `dot` localization types.  # noqa: E501

        :return: The x of this Localization.  # noqa: E501
        :rtype: float
        """
        return self._x

    @x.setter
    def x(self, x):
        """Sets the x of this Localization.

        Normalized horizontal position of left edge of bounding box for `box` localization types, start of line for `line` localization types, or position of dot for `dot` localization types.  # noqa: E501

        :param x: The x of this Localization.  # noqa: E501
        :type: float
        """
        if (self.local_vars_configuration.client_side_validation and
                x is not None and x > 1.0):  # noqa: E501
            raise ValueError("Invalid value for `x`, must be a value less than or equal to `1.0`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                x is not None and x < 0.0):  # noqa: E501
            raise ValueError("Invalid value for `x`, must be a value greater than or equal to `0.0`")  # noqa: E501

        self._x = x

    @property
    def y(self):
        """Gets the y of this Localization.  # noqa: E501

        Normalized vertical position of top edge of bounding box for `box` localization types, start of line for `line` localization types, or position of dot for `dot` localization types.  # noqa: E501

        :return: The y of this Localization.  # noqa: E501
        :rtype: float
        """
        return self._y

    @y.setter
    def y(self, y):
        """Sets the y of this Localization.

        Normalized vertical position of top edge of bounding box for `box` localization types, start of line for `line` localization types, or position of dot for `dot` localization types.  # noqa: E501

        :param y: The y of this Localization.  # noqa: E501
        :type: float
        """
        if (self.local_vars_configuration.client_side_validation and
                y is not None and y > 1.0):  # noqa: E501
            raise ValueError("Invalid value for `y`, must be a value less than or equal to `1.0`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                y is not None and y < 0.0):  # noqa: E501
            raise ValueError("Invalid value for `y`, must be a value greater than or equal to `0.0`")  # noqa: E501

        self._y = y

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Localization):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Localization):
            return True

        return self.to_dict() != other.to_dict()



import os
from ..openapi import tator_openapi as pytator

def get_api(host='https://www.tatorapp.com', token=os.getenv('TATOR_TOKEN')):
    """ Retrieves a TatorApi instance using the given host and token.

    :param host: URL of host. Default is https://www.tatorapp.com.
    :param token: API token.
    :returns: `TatorApi` object.
    """
    config = pytator.Configuration()
    config.host = host
    config.api_key['Authorization'] = token
    config.api_key_prefix['Authorization'] = 'Token'
    return pytator.TatorApi(pytator.ApiClient(config))



from setuptools import setup, find_packages  # noqa: H301
import tator

REQUIRES = ["urllib3 >= 1.15", "six >= 1.10", "certifi", "python-dateutil",
            "requests", "tator-tuspy"]

setup(
    name="tator",
    version=tator.__version__,
    description="Python client for Tator",
    author="CVision AI, Inc.",
    author_email="info@cvisionai.com",
    url="https://github.com/cvisionai/tator-py",
    keywords=["OpenAPI", "OpenAPI-Generator", "Tator"],
    install_requires=REQUIRES,
    packages=find_packages(exclude=["test", "tests"]),
    include_package_data=True,
    long_description="""\
    Python client for Tator.
    """
)



# coding: utf-8

"""
    Tator REST API

    Interface to the Tator backend.  # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from tator_openapi.configuration import Configuration


class ImageSpec(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'gid': 'str',
        'md5': 'str',
        'name': 'str',
        'section': 'str',
        'thumbnail_url': 'str',
        'type': 'int',
        'uid': 'str',
        'url': 'str'
    }

    attribute_map = {
        'gid': 'gid',
        'md5': 'md5',
        'name': 'name',
        'section': 'section',
        'thumbnail_url': 'thumbnail_url',
        'type': 'type',
        'uid': 'uid',
        'url': 'url'
    }

    def __init__(self, gid=None, md5=None, name=None, section=None, thumbnail_url=None, type=None, uid=None, url=None, local_vars_configuration=None):  # noqa: E501
        """ImageSpec - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._gid = None
        self._md5 = None
        self._name = None
        self._section = None
        self._thumbnail_url = None
        self._type = None
        self._uid = None
        self._url = None
        self.discriminator = None

        self.gid = gid
        self.md5 = md5
        self.name = name
        self.section = section
        if thumbnail_url is not None:
            self.thumbnail_url = thumbnail_url
        self.type = type
        self.uid = uid
        self.url = url

    @property
    def gid(self):
        """Gets the gid of this ImageSpec.  # noqa: E501

        UUID generated for the job group. This value is returned in the response of the `AlgorithmLaunch` and `Transcode` endpoints.  # noqa: E501

        :return: The gid of this ImageSpec.  # noqa: E501
        :rtype: str
        """
        return self._gid

    @gid.setter
    def gid(self, gid):
        """Sets the gid of this ImageSpec.

        UUID generated for the job group. This value is returned in the response of the `AlgorithmLaunch` and `Transcode` endpoints.  # noqa: E501

        :param gid: The gid of this ImageSpec.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and gid is None:  # noqa: E501
            raise ValueError("Invalid value for `gid`, must not be `None`")  # noqa: E501

        self._gid = gid

    @property
    def md5(self):
        """Gets the md5 of this ImageSpec.  # noqa: E501

        MD5 sum of the media file.  # noqa: E501

        :return: The md5 of this ImageSpec.  # noqa: E501
        :rtype: str
        """
        return self._md5

    @md5.setter
    def md5(self, md5):
        """Sets the md5 of this ImageSpec.

        MD5 sum of the media file.  # noqa: E501

        :param md5: The md5 of this ImageSpec.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and md5 is None:  # noqa: E501
            raise ValueError("Invalid value for `md5`, must not be `None`")  # noqa: E501

        self._md5 = md5

    @property
    def name(self):
        """Gets the name of this ImageSpec.  # noqa: E501

        Name of the file.  # noqa: E501

        :return: The name of this ImageSpec.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ImageSpec.

        Name of the file.  # noqa: E501

        :param name: The name of this ImageSpec.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def section(self):
        """Gets the section of this ImageSpec.  # noqa: E501

        Media section name.  # noqa: E501

        :return: The section of this ImageSpec.  # noqa: E501
        :rtype: str
        """
        return self._section

    @section.setter
    def section(self, section):
        """Sets the section of this ImageSpec.

        Media section name.  # noqa: E501

        :param section: The section of this ImageSpec.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and section is None:  # noqa: E501
            raise ValueError("Invalid value for `section`, must not be `None`")  # noqa: E501

        self._section = section

    @property
    def thumbnail_url(self):
        """Gets the thumbnail_url of this ImageSpec.  # noqa: E501

        Upload URL for the thumbnail if already generated.  # noqa: E501

        :return: The thumbnail_url of this ImageSpec.  # noqa: E501
        :rtype: str
        """
        return self._thumbnail_url

    @thumbnail_url.setter
    def thumbnail_url(self, thumbnail_url):
        """Sets the thumbnail_url of this ImageSpec.

        Upload URL for the thumbnail if already generated.  # noqa: E501

        :param thumbnail_url: The thumbnail_url of this ImageSpec.  # noqa: E501
        :type: str
        """

        self._thumbnail_url = thumbnail_url

    @property
    def type(self):
        """Gets the type of this ImageSpec.  # noqa: E501

        Unique integer identifying an image type. Use -1 to automatically select the image type if only one image type exists in a project.  # noqa: E501

        :return: The type of this ImageSpec.  # noqa: E501
        :rtype: int
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this ImageSpec.

        Unique integer identifying an image type. Use -1 to automatically select the image type if only one image type exists in a project.  # noqa: E501

        :param type: The type of this ImageSpec.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and type is None:  # noqa: E501
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                type is not None and type < -1):  # noqa: E501
            raise ValueError("Invalid value for `type`, must be a value greater than or equal to `-1`")  # noqa: E501

        self._type = type

    @property
    def uid(self):
        """Gets the uid of this ImageSpec.  # noqa: E501

        UUID generated for the individual job. This value is returned in the response of the `AlgorithmLaunch` and `Transcode` endpoints.  # noqa: E501

        :return: The uid of this ImageSpec.  # noqa: E501
        :rtype: str
        """
        return self._uid

    @uid.setter
    def uid(self, uid):
        """Sets the uid of this ImageSpec.

        UUID generated for the individual job. This value is returned in the response of the `AlgorithmLaunch` and `Transcode` endpoints.  # noqa: E501

        :param uid: The uid of this ImageSpec.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and uid is None:  # noqa: E501
            raise ValueError("Invalid value for `uid`, must not be `None`")  # noqa: E501

        self._uid = uid

    @property
    def url(self):
        """Gets the url of this ImageSpec.  # noqa: E501

        Upload URL for the image.  # noqa: E501

        :return: The url of this ImageSpec.  # noqa: E501
        :rtype: str
        """
        return self._url

    @url.setter
    def url(self, url):
        """Sets the url of this ImageSpec.

        Upload URL for the image.  # noqa: E501

        :param url: The url of this ImageSpec.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and url is None:  # noqa: E501
            raise ValueError("Invalid value for `url`, must not be `None`")  # noqa: E501

        self._url = url

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ImageSpec):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ImageSpec):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Tator REST API

    Interface to the Tator backend.  # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from tator_openapi.configuration import Configuration


class StateSpec(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'frame': 'int',
        'localization_ids': 'list[int]',
        'media_ids': 'list[int]',
        'modified': 'bool',
        'type': 'int',
        'version': 'int'
    }

    attribute_map = {
        'frame': 'frame',
        'localization_ids': 'localization_ids',
        'media_ids': 'media_ids',
        'modified': 'modified',
        'type': 'type',
        'version': 'version'
    }

    def __init__(self, frame=None, localization_ids=None, media_ids=None, modified=None, type=None, version=None, local_vars_configuration=None):  # noqa: E501
        """StateSpec - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._frame = None
        self._localization_ids = None
        self._media_ids = None
        self._modified = None
        self._type = None
        self._version = None
        self.discriminator = None

        if frame is not None:
            self.frame = frame
        if localization_ids is not None:
            self.localization_ids = localization_ids
        self.media_ids = media_ids
        self.modified = modified
        self.type = type
        if version is not None:
            self.version = version

    @property
    def frame(self):
        """Gets the frame of this StateSpec.  # noqa: E501

        Frame number this state applies to.  # noqa: E501

        :return: The frame of this StateSpec.  # noqa: E501
        :rtype: int
        """
        return self._frame

    @frame.setter
    def frame(self, frame):
        """Sets the frame of this StateSpec.

        Frame number this state applies to.  # noqa: E501

        :param frame: The frame of this StateSpec.  # noqa: E501
        :type: int
        """

        self._frame = frame

    @property
    def localization_ids(self):
        """Gets the localization_ids of this StateSpec.  # noqa: E501

        List of localization IDs that this state applies to.  # noqa: E501

        :return: The localization_ids of this StateSpec.  # noqa: E501
        :rtype: list[int]
        """
        return self._localization_ids

    @localization_ids.setter
    def localization_ids(self, localization_ids):
        """Sets the localization_ids of this StateSpec.

        List of localization IDs that this state applies to.  # noqa: E501

        :param localization_ids: The localization_ids of this StateSpec.  # noqa: E501
        :type: list[int]
        """

        self._localization_ids = localization_ids

    @property
    def media_ids(self):
        """Gets the media_ids of this StateSpec.  # noqa: E501

        List of media IDs that this state applies to.  # noqa: E501

        :return: The media_ids of this StateSpec.  # noqa: E501
        :rtype: list[int]
        """
        return self._media_ids

    @media_ids.setter
    def media_ids(self, media_ids):
        """Sets the media_ids of this StateSpec.

        List of media IDs that this state applies to.  # noqa: E501

        :param media_ids: The media_ids of this StateSpec.  # noqa: E501
        :type: list[int]
        """
        if self.local_vars_configuration.client_side_validation and media_ids is None:  # noqa: E501
            raise ValueError("Invalid value for `media_ids`, must not be `None`")  # noqa: E501

        self._media_ids = media_ids

    @property
    def modified(self):
        """Gets the modified of this StateSpec.  # noqa: E501

        Whether this state was created in the web UI.  # noqa: E501

        :return: The modified of this StateSpec.  # noqa: E501
        :rtype: bool
        """
        return self._modified

    @modified.setter
    def modified(self, modified):
        """Sets the modified of this StateSpec.

        Whether this state was created in the web UI.  # noqa: E501

        :param modified: The modified of this StateSpec.  # noqa: E501
        :type: bool
        """

        self._modified = modified

    @property
    def type(self):
        """Gets the type of this StateSpec.  # noqa: E501

        Unique integer identifying a state type.  # noqa: E501

        :return: The type of this StateSpec.  # noqa: E501
        :rtype: int
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this StateSpec.

        Unique integer identifying a state type.  # noqa: E501

        :param type: The type of this StateSpec.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and type is None:  # noqa: E501
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501

        self._type = type

    @property
    def version(self):
        """Gets the version of this StateSpec.  # noqa: E501

        Unique integer identifying the version.  # noqa: E501

        :return: The version of this StateSpec.  # noqa: E501
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this StateSpec.

        Unique integer identifying the version.  # noqa: E501

        :param version: The version of this StateSpec.  # noqa: E501
        :type: int
        """

        self._version = version

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, StateSpec):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, StateSpec):
            return True

        return self.to_dict() != other.to_dict()



from .openapi import *

from .util.get_api import get_api
from .util.get_parser import get_parser
from .util.chunked_create import chunked_create
from .util.download_media import download_media
from .util.download_temporary_file import download_temporary_file
from .util.upload_media import upload_media
from .util.upload_media_archive import upload_media_archive
from .util.chunked_file_list import chunked_file_list
from .util.upload_temporary_file import upload_temporary_file
from .util.md5sum import md5sum
from .util.get_images import get_images
from .util.to_dataframe import to_dataframe
from .version import __version__ as __version__
